@@ -17,7 +17,7 @@ pub use anyhow::{anyhow, Context as _};
 pub use derivative::Derivative;
 pub use flume::{bounded as bounded_ch, unbounded as unbounded_ch, Receiver, RecvError, Sender};
 pub use rand::{thread_rng, Rng};
-pub use strum_macros::IntoStaticStr;
+pub use strum::*;
 pub use tokio::time::{self, timeout, Duration, Instant};
 pub use tracing::{debug, error, event, info, trace, warn, Level};
 pub use tracing_tools::{span, TaskFut, TracingTask};
